@@ -94,7 +94,8 @@ glance_foot <- function(fit, col_pairs, total_cols,
   if (nrow(g) %% col_pairs > 0){
     n_fill <- (col_pairs - nrow(g) %% col_pairs)
     stat_fill <- data.frame(.rownames = rep("", n_fill),
-                            x = rep(NA, n_fill))
+                            x = rep(NA, n_fill),
+                            stringsAsFactors = FALSE)
     g <- dplyr::bind_rows(g, stat_fill)
   }
 
