@@ -1,21 +1,52 @@
 context("sprinkles")
 
+x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
+
+test_that(
+  "Cast an error if no sprinkles are given",
+  {
+    skip_on_cran()
+    expect_error(sprinkle(x),
+                 "At least one sprinkle")
+  }
+)
+
+test_that(
+  "Cast an error if unnamed sprinkles are given",
+  {
+    skip_on_cran()
+    expect_error(sprinkle(x, rows = 1, cols = 1, "green"),
+                 "Arguments to ... must be named")
+  }
+)
+
+test_that(
+  "Cast an error if a non-existent sprinkle is given",
+  {
+    skip_on_cran()
+    expect_error(sprinkle(x, not_a_sprinkle = "abc"),
+                 "could not be matched")
+  }
+)
+
 test_that("sprinkles: bg",
 {
-  x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
+  skip_on_cran()
   expect_equal(sprinkle(x, rows = 1, cols = 1, bg = "orchid")$body$bg[1],
-               "rgba(218,112,214,1)")
+               "orchid")
 })
 
 test_that("sprinkles: bg casts an error when 'bg' has length > 1",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, bg = c("orchid", "white")),
-               "")
+               "Variable 'bg'")
 })
 
 test_that("sprinkles: bg_pattern",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         bg_pattern = c("orchid", "aquamarine"))$body$bg[1:2],
@@ -31,6 +62,7 @@ test_that("sprinkles: bg_pattern",
 
 test_that("sprinkles: bg_pattern_by gives error when invalid option is given",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, bg_pattern_by = "diagonal"),
                "")
@@ -38,6 +70,7 @@ test_that("sprinkles: bg_pattern_by gives error when invalid option is given",
 
 test_that("sprinkles: bold",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, bold = TRUE)$body$bold[1],
                TRUE)
@@ -45,6 +78,7 @@ test_that("sprinkles: bold",
 
 test_that("sprinkles: bold errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, bold = c(1, 2)),
                "")
@@ -52,14 +86,16 @@ test_that("sprinkles: bold errors",
 
 test_that("sprinkles: border_collapse",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows=1, cols = 1, 
-                        border_collapse = FALSE)$border_collapse,
-               FALSE)
+                        border_collapse = "separate")$border_collapse,
+               "separate")
 })
 
 test_that("sprinkles: border_collapse errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, border_collapse = c(1, 0)),
                "")
@@ -67,14 +103,16 @@ test_that("sprinkles: border_collapse errors",
 
 test_that("sprinkles: border",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         border = c("left", "right"))$body$left_border[1],
-               "1px solid Black")
+               "1pt solid black")
 })
 
 test_that("sprinkles: border errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, border = "everything"),
                "")
@@ -82,14 +120,16 @@ test_that("sprinkles: border errors",
 
 test_that("sprinkles: border_thickness",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         border_thickness = 2)$body$top_border[1],
-               "2px solid Black")
+               "2pt solid black")
 })
 
 test_that("sprinkles: border_thickness errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, border_thickness = c(1, 2)),
                "")
@@ -97,14 +137,16 @@ test_that("sprinkles: border_thickness errors",
 
 test_that("sprinkles: border_units",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         border_units = "px")$body$top_border[1],
-               "1px solid Black")
+               "1px solid black")
 })
 
 test_that("sprinkles: border_units errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, border_units = c("inches")),
                "")
@@ -112,14 +154,16 @@ test_that("sprinkles: border_units errors",
 
 test_that("sprinkles: border_style",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         border_style = "dashed")$body$top_border[1],
-               "1px dashed Black")
+               "1pt dashed black")
 })
 
 test_that("sprinkles: border_style errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, border_style = c("halo")),
                "")
@@ -127,14 +171,16 @@ test_that("sprinkles: border_style errors",
 
 test_that("sprinkles: border_color",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         border_color = "Black")$body$top_border[1],
-               "1px solid rgba(0,0,0,1)")
+               "1pt solid Black")
 })
 
 test_that("sprinkles: border_color errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, border_color = 1),
                "")
@@ -142,6 +188,7 @@ test_that("sprinkles: border_color errors",
 
 test_that("sprinkles: halign",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         halign = "left")$body$halign[1],
@@ -150,6 +197,7 @@ test_that("sprinkles: halign",
 
 test_that("sprinkles: halign errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, halign = c("left", "right")),
                "")
@@ -157,6 +205,7 @@ test_that("sprinkles: halign errors",
                
 test_that("sprinkles: height",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, height = 12)$body$height[1],
                "12")
@@ -164,6 +213,7 @@ test_that("sprinkles: height",
 
 test_that("sprinkles: height errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, height = c(12, "text")),
                "")
@@ -171,6 +221,7 @@ test_that("sprinkles: height errors",
 
 test_that("sprinkles: height_units",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         height_units = "px")$body$height_units[1],
@@ -179,6 +230,7 @@ test_that("sprinkles: height_units",
 
 test_that("sprinkles: height_units errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, height_units = "em"),
                "")
@@ -186,6 +238,7 @@ test_that("sprinkles: height_units errors",
 
 test_that("sprinkles: fn",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         fn = quote(pvalString(value)))$body$fn[1],
@@ -194,14 +247,16 @@ test_that("sprinkles: fn",
 
 test_that("sprinkles: font_color",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         font_color = "orchid")$body$font_color[1],
-               "rgba(218,112,214,1)")
+               "orchid")
 })
            
 test_that("sprinkles: font_color error",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, font_color = c("orchid", "aquamarine")),
                "")
@@ -209,6 +264,7 @@ test_that("sprinkles: font_color error",
 
 test_that("sprinkles: font_size",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         font_size = 12)$body$font_size[1],
@@ -217,6 +273,7 @@ test_that("sprinkles: font_size",
 
 test_that("sprinkles: font_size errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, font_size = c("1", "x")),
                "")
@@ -224,6 +281,7 @@ test_that("sprinkles: font_size errors",
 
 test_that("sprinkles: font_size_units",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         font_size_units = "em")$body$font_size_units[1],
@@ -232,6 +290,7 @@ test_that("sprinkles: font_size_units",
 
 test_that("sprinkles: font_size_unit errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, font_size_units = c("inches")),
                "")
@@ -239,6 +298,7 @@ test_that("sprinkles: font_size_unit errors",
 
 test_that("sprinkles: italic",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         italic = TRUE)$body$italic[1],
@@ -247,6 +307,7 @@ test_that("sprinkles: italic",
 
 test_that("sprinkles: italic errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, italic = c(1, 2)),
                "")
@@ -254,6 +315,7 @@ test_that("sprinkles: italic errors",
 
 test_that("sprinkles: longtable accepts TRUE",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, longtable = TRUE)$longtable,
                TRUE)
@@ -261,6 +323,7 @@ test_that("sprinkles: longtable accepts TRUE",
 
 test_that("sprinkles: longtable accepts FALSE",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, longtable = FALSE)$longtable,
                FALSE)
@@ -268,6 +331,7 @@ test_that("sprinkles: longtable accepts FALSE",
 
 test_that("sprinkles: longtable accepts a number",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, longtable = 10)$longtable,
                10)
@@ -275,13 +339,14 @@ test_that("sprinkles: longtable accepts a number",
 
 test_that("sprinkles: longtable- character resolve to FALSE",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
-  expect_equal(sprinkle(x, longtable = "character")$longtable,
-               FALSE)
+  expect_error(sprinkle(x, longtable = "character"))
 })
 
 test_that("sprinkles: merge",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_silent(sprinkle(x, rows = 3:4, cols = 1:2, merge = TRUE,
                        merge_rowval = 4, merge_colval = 2))
@@ -289,30 +354,34 @@ test_that("sprinkles: merge",
 
 test_that("sprinkles: merge is not logical",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 3:4, cols = 1:2, merge = "yes please",
                        merge_rowval = 4, merge_colval = 2),
                "")
 })
 
-test_that("sprinkles: merge_rowval without merge casts error",
+test_that("sprinkles: merge_rowval without merge casts message",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
-  expect_error(sprinkle(x, rows = 3:4, cols = 1:2,
+  expect_message(sprinkle(x, rows = 3:4, cols = 1:2,
                        merge_rowval = 4),
                "")
 })
 
-test_that("sprinkles: merge_colval without merge casts error",
+test_that("sprinkles: merge_colval without merge casts message",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
-  expect_error(sprinkle(x, rows = 3:4, cols = 1:2,
+  expect_message(sprinkle(x, rows = 3:4, cols = 1:2,
                        merge_colval = 4),
                "")
 })
 
 test_that("sprinkles: na_string",
 {
+  skip_on_cran()
   x <- dust(aov(mpg ~ factor(am) + factor(gear), data = mtcars))
   expect_equal(sprinkle(x, na_string = "")$body$na_string,
                rep("", 18))
@@ -320,6 +389,7 @@ test_that("sprinkles: na_string",
 
 test_that("sprinkles: na_string not character",
 {
+  skip_on_cran()
   x <- dust(aov(mpg ~ factor(am) + factor(gear), data = mtcars))
   expect_error(sprinkle(x, na_string = 1),
                "")
@@ -327,6 +397,7 @@ test_that("sprinkles: na_string not character",
 
 test_that("sprinkles: pad",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, pad = 5)$body$pad[1],
                "5")
@@ -334,6 +405,7 @@ test_that("sprinkles: pad",
 
 test_that("sprinkles: pad errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, pad = c(1, "text")),
                "")
@@ -341,6 +413,7 @@ test_that("sprinkles: pad errors",
 
 test_that("sprinkles: replace",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, replace = "Intercept")$body$replace[1],
               "Intercept")
@@ -348,6 +421,7 @@ test_that("sprinkles: replace",
 
 test_that("sprinkles: replace errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, 
                         replace = c("Intercept", "1/4 Mile Time")),
@@ -356,6 +430,7 @@ test_that("sprinkles: replace errors",
 
 test_that("sprinkles: round",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, round = 5)$body$round[1],
                "5")
@@ -363,6 +438,7 @@ test_that("sprinkles: round",
 
 test_that("sprinkles: round errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, round = c(1, "text")),
                "")
@@ -370,6 +446,7 @@ test_that("sprinkles: round errors",
 
 test_that("sprinkles: rotate_degree",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         rotate_degree = 5)$body$rotate_degree[1],
@@ -378,6 +455,7 @@ test_that("sprinkles: rotate_degree",
 
 test_that("sprinkles: rotate_degree errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, rotate_degree = c(1, "text")),
                "")
@@ -385,6 +463,7 @@ test_that("sprinkles: rotate_degree errors",
 
 test_that("sprinkles: valign",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, valign = "middle")$body$valign[1],
                "middle")
@@ -392,6 +471,7 @@ test_that("sprinkles: valign",
 
 test_that("sprinkles: valign errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, valign = "above"),
                "")
@@ -399,6 +479,7 @@ test_that("sprinkles: valign errors",
 
 test_that("sprinkles: width",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, width = 12)$body$width[1],
                "12")
@@ -406,6 +487,7 @@ test_that("sprinkles: width",
 
 test_that("sprinkles: width errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, width = c(12, "text")),
                "")
@@ -413,6 +495,7 @@ test_that("sprinkles: width errors",
 
 test_that("sprinkles: width_units",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_equal(sprinkle(x, rows = 1, cols = 1, 
                         width_units = "px")$body$width_units[1],
@@ -421,6 +504,7 @@ test_that("sprinkles: width_units",
 
 test_that("sprinkles: width_units errors",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, width_units = "em"),
                "")
@@ -428,6 +512,7 @@ test_that("sprinkles: width_units errors",
 
 test_that("sprinkles: no sprinkles given",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data=mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1),
                "")
@@ -435,6 +520,7 @@ test_that("sprinkles: no sprinkles given",
 
 test_that("sprinkles: single unnamed sprinkle",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, "green"),
                "")
@@ -442,6 +528,7 @@ test_that("sprinkles: single unnamed sprinkle",
 
 test_that("sprinkles: multiple unnamed sprinkles",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, "green", "dotted"),
                "")
@@ -449,6 +536,7 @@ test_that("sprinkles: multiple unnamed sprinkles",
 
 test_that("sprinkles: mixture of named and unnamed sprinkles",
 {
+  skip_on_cran()
   x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars))
   expect_error(sprinkle(x, rows = 1, cols = 1, border_color = "green", "dotted"),
                "")
@@ -458,9 +546,10 @@ test_that("sprinkles: mixture of named and unnamed sprinkles",
 test_that(
   "sprinkles: fixed argument",
   {
+    skip_on_cran()
     x <- dust(lm(mpg ~ qsec + factor(am) + wt, data = mtcars)) %>%
-      sprinkle(cols = 1:5,
-               rows = 1:5,
+      sprinkle(cols = c(1, 2, 3),
+               rows = c(1, 2, 3),
                bg = "green",
                fixed = TRUE) 
     expect_output(print(x))
@@ -471,6 +560,7 @@ test_that(
 test_that(
   "sprinkles: longtable",
   {
+    skip_on_cran()
     expect_silent(
       dust(mtcars) %>%
         sprinkle(longtable = 10)
